Crate rs_ws281x

source ·

Modules

Structs

  • A struct used to build a channel configuration for a ControllerBuilder.
  • The main struct used to control lights. Provides ways of accessing the light color values and rendering those values to the string.
  • A struct to assist in the process of initializing a Controller instance. One is pretty much required to use this to construct a Controller, unless one happens to have an instance of ws2811_t sitting around.

Enums

Type Aliases